Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ReplacedEndDeviceField ¶
type ReplacedEndDeviceField struct {
Old string
New string
GetTransform func(dev *ttnpb.EndDevice)
SetTransform func(dev *ttnpb.EndDevice, useOld, useNew bool) error
}
ReplacedEndDeviceField provides how to transform an old End Device field to a new field.
type ReplacedEndDeviceFieldMatch ¶
type ReplacedEndDeviceFieldMatch struct {
ReplacedEndDeviceField
MatchedOld bool
MatchedNew bool
}
ReplacedEndDeviceFieldMatch provides information about an End Device field replacement based on usage of the old name, new name or both.
func MatchReplacedEndDeviceFields ¶
func MatchReplacedEndDeviceFields(paths []string, replaced []ReplacedEndDeviceField) ([]string, []ReplacedEndDeviceFieldMatch)
MatchReplacedEndDeviceFields returns a set of ReplacedEndDeviceFieldMatch based on usage by the given paths.
Click to show internal directories.
Click to hide internal directories.